pyNSID
======

Framework for storing, visualizing, and processing N-Dimensional Spectroscopic and Imaging Data (NSID)

Please see our `website <https://pycroscopy.github.io/pyNSID/about.html>`_ for more information.

**This package is under development**
